@@ -10,6 +10,8 @@ from django.db.models.signals import post_delete
 from django.dispatch import receiver
 from virtualization.models import VirtualMachine
 
+import ptuevents.models
+
 
 class PTUEvent(NetBoxModel):
     name = models.CharField(
@@ -238,6 +240,7 @@ class PTUsers(NetBoxModel):
 
     class Meta:
         ordering = ['name']
+        verbose_name_plural = 'Users'
 
     def __str__(self):
         return self.name
@@ -246,6 +249,41 @@ class PTUsers(NetBoxModel):
         return reverse('plugins:ptuevents:ptusers', args=[self.pk])
 
 
+class PTUsersAssignment(WebhooksMixin, ChangeLoggedModel):
+    content_type = models.ForeignKey(
+        to=ContentType,
+        on_delete=models.CASCADE
+    )
+    object_id = models.PositiveBigIntegerField()
+    object = GenericForeignKey(
+        ct_field='content_type',
+        fk_field='object_id'
+    )
+    ptuevent = models.ForeignKey(
+        to='ptuevents.ptuevent',
+        on_delete=models.PROTECT,
+        related_name='ptuevent_assignments'
+    )
+    relation = models.ForeignKey(
+        to='ptuevents.PTUEventRelation',
+        on_delete=models.PROTECT,
+        related_name='ptuevent_assignments'
+    )
+
+    clone_fields = ('content_type', 'object_id')
+
+    class Meta:
+        ordering = ['ptuevent']
+        unique_together = ('content_type', 'object_id',
+                           'ptuevent', 'relation')
+
+    def __str__(self):
+        return str(self.app_system)
+
+    def get_absolute_url(self):
+        return reverse('plugins:ptuevents:ptusers', args=[self.app_system.pk])
+
+
 class PTWorkstations(NetBoxModel):
 
     name = models.CharField(
@@ -282,6 +320,7 @@ class PTWorkstations(NetBoxModel):
 
     class Meta:
         ordering = ['name']
+        verbose_name_plural = 'Workstations'
 
     def __str__(self):
         return self.name
@@ -289,3 +328,56 @@ class PTWorkstations(NetBoxModel):
     def get_absolute_url(self):
         return reverse('plugins:ptuevents:ptworkstations', args=[self.pk])
 
+
+class PTWorkstationsAssignment(WebhooksMixin, ChangeLoggedModel):
+    content_type = models.ForeignKey(
+        to=ContentType,
+        on_delete=models.CASCADE
+    )
+    object_id = models.PositiveBigIntegerField()
+    object = GenericForeignKey(
+        ct_field='content_type',
+        fk_field='object_id'
+    )
+    ptuevent = models.ForeignKey(
+        to='ptuevents.ptuevent',
+        on_delete=models.PROTECT,
+        related_name='ptuevent_assignments'
+    )
+    relation = models.ForeignKey(
+        to='ptuevents.PTUEventRelation',
+        on_delete=models.PROTECT,
+        related_name='ptuevent_assignments'
+    )
+
+    clone_fields = ('content_type', 'object_id')
+
+    class Meta:
+        ordering = ['ptuevent']
+        unique_together = ('content_type', 'object_id',
+                           'ptuevent', 'relation')
+
+    def __str__(self):
+        return str(self.app_system)
+
+    def get_absolute_url(self):
+        return reverse('plugins:ptuevents:ptworkstations', args=[self.app_system.pk])
+
+
+@receiver(post_delete, sender=PTUsers, dispatch_uid='del_PTUEvent_assignment')
+def del_assignments(sender, **kwargs):
+    content_type_id = ContentType.objects.get(model='ptusers').id
+    instance_id = kwargs.get('instance').id
+    objs = PTUEventAssignment.objects.filter(
+        object_id=instance_id, content_type=content_type_id)
+    objs.delete()
+
+
+@receiver(post_delete, sender=PTWorkstations, dispatch_uid='del_PTUEvent_assignment')
+def del_assignments(sender, **kwargs):
+    content_type_id = ContentType.objects.get(model='ptworkstations').id
+    instance_id = kwargs.get('instance').id
+    objs = PTUEventAssignment.objects.filter(
+            object_id=instance_id, content_type=content_type_id)
+    objs.delete()
+
